==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ZoomSliderResolvingAxisValueEventArgsDescription } from "./ZoomSliderResolvingAxisValueEventArgsDescription";
/**
 * @hidden
 */
var ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata, _super);
    function ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.b = function (a) {
        if (ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.a == null) {
            ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.c(ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.a);
        }
        if (a.g(ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.a);
    };
    ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.c = function (a) {
        a.item("Position", "Number:double");
        a.item("ValueRef", "(w:Value,wf:Value)DataRef");
    };
    ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.d = function (a) {
        ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.b(a);
        a.u("ZoomSliderResolvingAxisValueEventArgs", function () { return new ZoomSliderResolvingAxisValueEventArgsDescription(); });
        a.t("ZoomSliderResolvingAxisValueEventArgs", ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.a);
    };
    ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.$t = markType(ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata, 'ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata');
    ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.a = null;
    return ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata;
}(Base));
export { ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ZoomSliderResolvingAxisValueEventArgsDescription } from "./ZoomSliderResolvingAxisValueEventArgsDescription";
/**
 * @hidden
 */
var ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata, _super);
    function ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.b = function (a) {
        if (ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.a == null) {
            ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.c(ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.a);
        }
        if (a.j(ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.a);
    };
    ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.c = function (a) {
        a.item("Position", "Number:double");
        a.item("ValueRef", "(w:Value,wf:Value)DataRef");
    };
    ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.d = function (a) {
        ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.b(a);
        a.aa("ZoomSliderResolvingAxisValueEventArgs", function () { return new ZoomSliderResolvingAxisValueEventArgsDescription(); });
        a.z("ZoomSliderResolvingAxisValueEventArgs", ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.a);
    };
    ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.$t = markType(ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata, 'ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata');
    ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.a = null;
    return ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata;
}(Base));
export { ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata };
